Enum StateChangePostBlockSource
pub enum StateChangePostBlockSource {
BalanceIncrements,
WithdrawalRequestsContract,
ConsolidationRequestsContract,
Other(&'static str),
}Expand description
Source of a post-block state change caused by a system call or balance modification that executes after all transactions in the block have been processed.
Variants
BalanceIncrements
Balance increments applied for block rewards (e.g. beacon withdrawals, ommer rewards).
WithdrawalRequestsContract
EIP-7002: processes withdrawal requests contract after block execution.
ConsolidationRequestsContract
EIP-7251: processes the consolidation requests contract to handle queued validator consolidations.
Other(&'static str)
A custom post-block state change not covered by the standard variants.