Struct EthInstructions
pub struct EthInstructions<WIRE, HOST>where
WIRE: InterpreterTypes,
HOST: ?Sized,{
pub spec: SpecId,
/* private fields */
}Expand description
Ethereum instruction contains list of mainnet instructions that is used for Interpreter execution.
Fields
spec: SpecIdSpec that is used to set gas costs for instructions.
Implementations
impl<WIRE, HOST> EthInstructions<WIRE, HOST>where
WIRE: InterpreterTypes,
HOST: Host,
impl<WIRE, HOST> EthInstructions<WIRE, HOST>where
WIRE: InterpreterTypes,
HOST: Host,
pub fn new_mainnet() -> EthInstructions<WIRE, HOST>
👎Deprecated since 0.2.0: use new_mainnet_with_spec instead
pub fn new_mainnet() -> EthInstructions<WIRE, HOST>
use new_mainnet_with_spec instead
Returns EthInstructions with mainnet spec.
pub fn new_mainnet_with_spec(spec: SpecId) -> EthInstructions<WIRE, HOST>
pub fn new_mainnet_with_spec(spec: SpecId) -> EthInstructions<WIRE, HOST>
Returns EthInstructions with mainnet spec.
pub fn new(
instruction_table: [Instruction<WIRE, HOST>; 256],
gas_table: [u16; 256],
spec: SpecId,
) -> EthInstructions<WIRE, HOST>
pub fn new( instruction_table: [Instruction<WIRE, HOST>; 256], gas_table: [u16; 256], spec: SpecId, ) -> EthInstructions<WIRE, HOST>
Returns a new instance of EthInstructions with custom instruction and gas tables.
pub fn insert_instruction(
&mut self,
opcode: u8,
instruction: Instruction<WIRE, HOST>,
gas: u16,
)
pub fn insert_instruction( &mut self, opcode: u8, instruction: Instruction<WIRE, HOST>, gas: u16, )
Inserts a new instruction into the instruction table.
pub fn insert_gas(&mut self, opcode: u8, gas: u16)
pub fn insert_gas(&mut self, opcode: u8, gas: u16)
Inserts a new gas cost into the gas table.
pub fn instruction_table(&self) -> &[Instruction<WIRE, HOST>; 256]
pub fn instruction_table(&self) -> &[Instruction<WIRE, HOST>; 256]
Returns a reference to the instruction table.
pub fn instruction_table_mut(&mut self) -> &mut [Instruction<WIRE, HOST>; 256]
pub fn instruction_table_mut(&mut self) -> &mut [Instruction<WIRE, HOST>; 256]
Returns a mutable reference to the instruction table.
pub fn gas_table_mut(&mut self) -> &mut [u16; 256]
pub fn gas_table_mut(&mut self) -> &mut [u16; 256]
Returns a mutable reference to the gas table.