InspectorFrame

Trait InspectorFrame 

pub trait InspectorFrame: FrameTr<FrameResult = FrameResult, FrameInit = FrameInit> {
    type IT: InterpreterTypes;

    // Required method
    fn eth_frame(&mut self) -> Option<&mut EthFrame>;
}
Trait that extends the FrameTr trait with additional functionality that is needed for inspection.

Required Associated Types

type IT: InterpreterTypes

The interpreter types used by this frame.

Required Methods

fn eth_frame(&mut self) -> Option<&mut EthFrame>

Returns a mutable reference to the EthFrame.

If this frame does not have support for tracing (does not contain the EthFrame) Inspector calls for this frame will be skipped.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors



impl InspectorFrame for EthFrame

Impl InspectorFrame for EthFrame.