StorageKeyMap

Type Alias StorageKeyMap 

pub type StorageKeyMap<V> = HashMap<Uint<256, 4>, V, FbBuildHasher<32>>;
Type alias for a map with storage keys (U256) as keys.

Aliased Type

pub struct StorageKeyMap<V> { /* private fields */ }

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 40 bytes