ExecutableTxIterator

Trait ExecutableTxIterator 

pub trait ExecutableTxIterator<Evm: ConfigureEvm>: ExecutableTxTuple<Tx: ExecutableTxFor<Evm, Recovered = Self::Recovered>> {
    type Recovered: RecoveredTx<TxTy<Evm::Primitives>> + Send + Sync;
}
Available on crate feature std only.
Iterator over executable transactions.

See also ExecutableTxTuple for the raw transaction iterator and converter this extension trait builds on.

Required Associated Types

type Recovered: RecoveredTx<TxTy<Evm::Primitives>> + Send + Sync

HACK: for some reason, this duplicated AT is the only way to enforce the inner Recovered: Send + Sync bound. Effectively alias for Self::Tx::Recovered.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, Evm: ConfigureEvm> ExecutableTxIterator<Evm> for T
where T: ExecutableTxTuple<Tx: ExecutableTxFor<Evm, Recovered: Send + Sync>>,