Trait ReceiptBuilder
pub trait ReceiptBuilder {
type Transaction: TransactionEnvelope;
type Receipt;
// Required method
fn build_receipt<E>(
&self,
ctx: ReceiptBuilderCtx<'_, <Self::Transaction as TransactionEnvelope>::TxType, E>,
) -> Self::Receipt
where E: Evm;
}Expand description
Type that knows how to build a receipt based on execution result.
Required Associated Types
type Transaction: TransactionEnvelope
type Transaction: TransactionEnvelope
Transaction type.
type Receipt
type Receipt
Receipt type.
Required Methods
fn build_receipt<E>(
&self,
ctx: ReceiptBuilderCtx<'_, <Self::Transaction as TransactionEnvelope>::TxType, E>,
) -> Self::Receiptwhere
E: Evm,
fn build_receipt<E>(
&self,
ctx: ReceiptBuilderCtx<'_, <Self::Transaction as TransactionEnvelope>::TxType, E>,
) -> Self::Receiptwhere
E: Evm,
Builds a receipt given a transaction and the result of the execution.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".