Function dupn
pub fn dupn<IT, H>(
context: InstructionContext<'_, H, IT>,
) -> Result<(), InstructionResult>where
IT: InterpreterTypes,
H: ?Sized,Expand description
Implements the DUPN instruction.
Duplicates the Nth stack item to the top of the stack, with N given by an immediate.